MicroPython documentation and references
========================================

.. toctree::

    library/index.rst
    reference/index.rst
    genrst/index.rst
    develop/index.rst
    license.rst
    pyboard/quickref.rst
    esp8266/quickref.rst
    esp32/quickref.rst
    rp2/quickref.rst
    mimxrt/quickref.rst
    wipy/quickref.rst
    unix/quickref.rst
    zephyr/quickref.rst
    renesas-ra/quickref.rst
    samd/quickref.rst
